@@ -5,6 +5,7 @@
 #include "cweekwidget.h"
 #include "calendarmanage.h"
 #include "constants.h"
+#include "commondef.h"
 #include <QLocale>
 #include <QPainter>
 #include <QDate>
@@ -12,6 +13,7 @@
 CWeekWidget::CWeekWidget(QWidget *parent) : QPushButton(parent)
   , m_firstDay(CalendarManager::getInstance()->getFirstDayOfWeek())
 {
+    qCDebug(ClientLogger) << "CWeekWidget constructor";
     setMinimumHeight(10);
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
     setFocusPolicy(Qt::NoFocus);
@@ -19,22 +21,26 @@ CWeekWidget::CWeekWidget(QWidget *parent) : QPushButton(parent)
 
 void CWeekWidget::setFirstDay(Qt::DayOfWeek first)
 {
+    qCDebug(ClientLogger) << "CWeekWidget::setFirstDay first:" << first;
     m_firstDay = first;
     setAutoFirstDay(true);
 }
 
 void CWeekWidget::setAutoFirstDay(bool is)
 {
+    qCDebug(ClientLogger) << "CWeekWidget::setAutoFirstDay is:" << is;
     m_autoFirstDay = is;
 }
 
 void CWeekWidget::setAutoFontSizeByWindow(bool is)
 {
+    qCDebug(ClientLogger) << "CWeekWidget::setAutoFontSizeByWindow is:" << is;
     m_autoFontSizeByWindow = is;
 }
 
 void CWeekWidget::paintEvent(QPaintEvent *event)
 {
+    // qCDebug(ClientLogger) << "CWeekWidget::paintEvent";
     QWidget::paintEvent(event);
     QPainter painter(this);
     painter.setRenderHint(QPainter::Antialiasing);
@@ -42,12 +48,14 @@ void CWeekWidget::paintEvent(QPaintEvent *event)
     QFont font;
 
     if (m_autoFontSizeByWindow) {
+        // qCDebug(ClientLogger) << "CWeekWidget::paintEvent - Auto font size by window";
         //字体跟随界面大小
         qreal w = this->width() / 7;
         qreal h = this->height();
         qreal r = w > h ? h : w ;
 
         if (QLocale::system().language() == QLocale::English) {
+            // qCDebug(ClientLogger) << "CWeekWidget::paintEvent - English locale, reducing font size";
             r*=0.8;
         }
 
@@ -56,6 +64,7 @@ void CWeekWidget::paintEvent(QPaintEvent *event)
         font.setPixelSize(int(r/20.0*12));
 
     } else {
+        // qCDebug(ClientLogger) << "CWeekWidget::paintEvent - Fixed font size";
         font.setPixelSize(DDECalendar::FontSizeTwelve);
     }
 
@@ -66,16 +75,14 @@ void CWeekWidget::paintEvent(QPaintEvent *event)
     //获取一周首日
     int firstDay = m_firstDay;
     if (m_autoFirstDay) {
+        // qCDebug(ClientLogger) << "CWeekWidget::paintEvent - Auto first day";
         firstDay = CalendarManager::getInstance()->getFirstDayOfWeek();
     }
 
     QStringList weekStr;
-    for (int i = 0; i < 8; i++) {
-        // 2024/8/15 星期四是deepin23的发布日期
-        // 减4是从周日开始将所有星期名字都写到weekStr，取代之前手动翻译方式
-        QDate date(2024, 8, 15 - 4 + i);
-        QString weekDayName = locale.toString(date, "ddd");
-        weekStr<<weekDayName;
+    for (auto i : { 7, 1, 2, 3, 4, 5, 6 }) {
+        QString weekDayName = locale.dayName(i, QLocale::NarrowFormat);
+        weekStr << weekDayName;
     }
 
     //绘制周一到周日
