@@ -42,6 +42,7 @@ DHuangLiDataBase::DHuangLiDataBase(QObject *parent)
 // readJSON 会读取一个JSON文件，如果 cache 为 true，则会缓存对象，以供下次使用
 QJsonDocument DHuangLiDataBase::readJSON(QString filename, bool cache)
 {
+    qCDebug(ServiceLogger) << "Reading JSON file:" << filename << "with cache:" << cache;
     if (cache && readJSONCache.contains(filename)) {
         qCDebug(ServiceLogger) << "Using cached JSON data for file:" << filename;
         return readJSONCache.value(filename);
@@ -52,8 +53,10 @@ QJsonDocument DHuangLiDataBase::readJSON(QString filename, bool cache)
     if (!file.open(QIODevice::ReadOnly)) {
         qCWarning(ServiceLogger) << "Failed to open JSON file:" << filename << "Error:" << file.errorString();
     } else {
+        qCDebug(ServiceLogger) << "Successfully opened JSON file:" << filename;
         auto data = file.readAll();
         doc = QJsonDocument::fromJson(data);
+        qCDebug(ServiceLogger) << "Parsed JSON document from file:" << filename;
     }
     readJSONCache.insert(filename, doc);
     return readJSONCache.value(filename);
@@ -61,6 +64,7 @@ QJsonDocument DHuangLiDataBase::readJSON(QString filename, bool cache)
 
 void DHuangLiDataBase::updateFestivalList()
 {
+    qCDebug(ServiceLogger) << "Starting festival list update process";
     auto now = QDateTime::currentDateTime();
     auto festivalUpdateDate = now.toString("yyyy-MM-dd");
     // 每天更新一次
@@ -81,6 +85,7 @@ void DHuangLiDataBase::updateFestivalList()
             qCWarning(ServiceLogger) << "Download error for year" << year << ":" << process->readAllStandardError();
         });
     }
+    qCDebug(ServiceLogger) << "Completed festival list update process";
 }
 
 // queryFestivalList 查询指定月份的节假日列表
@@ -90,15 +95,19 @@ QJsonArray DHuangLiDataBase::queryFestivalList(quint32 year, quint8 month)
     QJsonArray dataset;
     QFile file(QString("%1/%2.json").arg(HolidayDir).arg(year));
     if (file.open(QIODevice::ReadOnly)) {
+        qCDebug(ServiceLogger) << "Successfully opened festival data file for year:" << year;
         auto data = file.readAll();
         file.close();
         auto doc = QJsonDocument::fromJson(data);
-        for (auto val : doc.object().value("days").toArray()) {
+        auto daysArray = doc.object().value("days").toArray();
+        qCDebug(ServiceLogger) << "Processing" << daysArray.size() << "festival entries for year:" << year;
+        for (auto val : daysArray) {
             auto day = val.toObject();
             auto name = day.value("name").toString();
             auto date = QDate::fromString(day.value("date").toString(), "yyyy-MM-dd");
             auto isOffday = day.value("isOffDay").toBool();
             if (quint32(date.year()) == year && quint32(date.month()) == month) {
+                qCDebug(ServiceLogger) << "Found matching festival entry:" << name << "date:" << date.toString() << "isOffDay:" << isOffday;
                 QJsonObject obj;
                 obj.insert("name", name);
                 obj.insert("date", date.toString("yyyy-MM-dd"));
@@ -107,17 +116,22 @@ QJsonArray DHuangLiDataBase::queryFestivalList(quint32 year, quint8 month)
             }
         }
         file.close();
+    } else {
+        qCWarning(ServiceLogger) << "Failed to open festival data file for year:" << year;
     }
+    qCDebug(ServiceLogger) << "Found" << dataset.size() << "festival entries for year:" << year << "month:" << month;
     return dataset;
 }
 
 QList<stHuangLi> DHuangLiDataBase::queryHuangLiByDays(const QList<stDay> &days)
 {
+    qCDebug(ServiceLogger) << "Querying HuangLi data for" << days.size() << "days";
     QList<stHuangLi> infos;
     SqliteQuery query(m_database);
     foreach (stDay d, days) {
         // 查询的id
         qint64 id = QString().asprintf("%d%02d%02d", d.Year, d.Month, d.Day).toInt();
+        qCDebug(ServiceLogger) << "Querying HuangLi data for date:" << d.Year << "-" << d.Month << "-" << d.Day << "with id:" << id;
         QString strsql("SELECT id, avoid, suit FROM huangli WHERE id = %1");
         strsql = strsql.arg(id);
         // 数据库中的宜忌信息是从2008年开始的
@@ -126,19 +140,30 @@ QList<stHuangLi> DHuangLiDataBase::queryHuangLiByDays(const QList<stDay> &days)
         sthuangli.ID = id;
         // 如果数据库中有查询到数据，则进行赋值，如果没有，则使用初始值
         if (query.exec(strsql) && query.next()) {
+            qCDebug(ServiceLogger) << "Found HuangLi data in database for id:" << id;
             sthuangli.ID = query.value("id").toInt();
             sthuangli.Avoid = query.value("avoid").toString();
             sthuangli.Suit = query.value("suit").toString();
+        } else {
+            qCDebug(ServiceLogger) << "No HuangLi data found in database for id:" << id << ", using default values";
         }
         // 将黄历数据放到list中
         infos.append(sthuangli);
     }
     if (query.isActive()) {
+        qCDebug(ServiceLogger) << "Finishing HuangLi query";
         query.finish();
     }
+    qCDebug(ServiceLogger) << "Retrieved HuangLi data for" << infos.size() << "days";
     return infos;
 }
 
-void DHuangLiDataBase::initDBData() { }
+void DHuangLiDataBase::initDBData()
+{
+    qCDebug(ServiceLogger) << "Initializing HuangLi database data (placeholder method)";
+}
 
-void DHuangLiDataBase::createDB() { }
+void DHuangLiDataBase::createDB()
+{
+    qCDebug(ServiceLogger) << "Creating HuangLi database (placeholder method)";
+}
